@@ -11,11 +11,11 @@ use 5.006;
 use strict;
 use warnings;
 package Metabase::Fact::Hash;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 # ABSTRACT: fact subtype for simple hashes
 
 use Carp ();
-use JSON ();
+use JSON 2 ();
 
 use base 'Metabase::Fact';
 
@@ -41,12 +41,12 @@ sub validate_content {
 
 sub content_as_bytes {
   my ($self) = @_;
-  return JSON->new->encode($self->content);
+  return JSON->new->ascii->encode($self->content);
 }
 
 sub content_from_bytes { 
   my ($class, $bytes) = @_;
-  return JSON->new->decode($bytes);
+  return JSON->new->ascii->decode($bytes);
 }
 
 1;
@@ -61,7 +61,7 @@ Metabase::Fact::Hash - fact subtype for simple hashes
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
