@@ -11,11 +11,11 @@ use 5.006;
 use strict;
 use warnings;
 package Metabase::Report;
-our $VERSION = '0.008';
+our $VERSION = '0.009';
 # ABSTRACT: a base class for collections of Metabase facts
 
 use Carp ();
-use JSON ();
+use JSON 2 ();
 
 use base 'Metabase::Fact';
 
@@ -134,7 +134,7 @@ sub content_as_bytes {
   Carp::confess("can't serialize an open report") unless $self->{__closed};
 
   my $content = [ map { $_->as_struct } @{ $self->content } ];
-  my $encoded = eval { JSON->new->encode( $content ) };
+  my $encoded = eval { JSON->new->ascii->encode( $content ) };
   Carp::confess $@ if $@;
   return $encoded;
 }
@@ -143,7 +143,7 @@ sub content_from_bytes {
   my ($self, $string) = @_;
   $string = $$string if ref $string;
 
-  my $fact_structs = JSON->new->decode( $string );
+  my $fact_structs = JSON->new->ascii->decode( $string );
 
   my @facts;
   for my $struct (@$fact_structs) {
@@ -230,7 +230,7 @@ Metabase::Report - a base class for collections of Metabase facts
 
 =head1 VERSION
 
-version 0.008
+version 0.009
 
 =head1 SYNOPSIS
 
